@@ -2,7 +2,7 @@
 #include "runFunctions.h"
 #include "runTest.h"
 #include "RankCluster.h"
-#ifdef SUPPORT_OPENMP
+#ifdef _OPENMP
 #include <omp.h>
 #endif
 
@@ -143,7 +143,7 @@ RcppExport SEXP loglikelihood(SEXP X,SEXP mu,SEXP p, SEXP proportion,SEXP m, SEX
   vector<double> L(nbRun,0), bic(nbRun,0), icl(nbRun,0);
 
   
-  #ifdef SUPPORT_OPENMP
+  #ifdef _OPENMP
   nb = std::min(nb, omp_get_num_procs());
   #pragma omp parallel num_threads(nb)
   {
